﻿using System.Windows;
using System.Windows.Interactivity;

namespace MetroWindow.Interactivity
{
    /// <summary>
    /// Sets the designated property to the supplied value. TargetObject
    /// optionally designates the object on which to set the property. If
    /// TargetObject is not supplied then the property is set on the object
    /// to which the trigger is attached.
    /// </summary>
    public class WindowAction : TriggerAction<FrameworkElement>
    {
        /// <summary>
        /// The property to be executed in response to the trigger.
        /// </summary>
        public string Action
        {
            get { return (string)GetValue(ActionProperty); }
            set { SetValue(ActionProperty, value); }
        }

        public static readonly DependencyProperty ActionProperty
            = DependencyProperty.Register("Action", typeof(string), typeof(WindowAction));

        /// <summary>
        /// 
        /// </summary>
        /// <param name="parameter"></param>
        protected override void Invoke(object parameter)
        {
            var window = Window.GetWindow(this.AssociatedObject);

            if (this.Action == "Minimize")
                window.WindowState = WindowState.Minimized;
            else if (this.Action == "Close")
                window.Close();
        }
    }
}